@@ -4,12 +4,13 @@ use 5.006;
 use strict;
 use warnings;
 use Scalar::Util qw/blessed reftype refaddr/;
-use parent 'Types::Standard';
 
+use parent 'Types::Standard';
+ 
 our @EXPORT_OK = ( Types::Standard->type_names );
 
 our $meta = __PACKAGE__->meta;
-our $VERSION = '0.000004';
+our $VERSION = '0.000005';
 
 our (%entity, %recurse, %compare, $esc, $unesc, $path);
 BEGIN {
@@ -109,6 +110,34 @@ sub _strToHash {
 	}
 }
 
+$meta->add_type({
+	name => 'StrSR',
+	parent => scalar $meta->Str,
+	abuse_constraint => \&search_replace_constraint,
+	abuse => \&search_replace
+});
+
+sub search_replace_constraint {
+	my ($sr) = (quotemeta($_[0][0]));
+	return sub {
+		my $str = shift;
+		! ($str =~ m/$sr/);
+	};
+}
+
+sub search_replace {
+	my (@sr) = (quotemeta($_[0][0]), $_[0][1]);
+	return sub {
+		my $str = shift;
+		ref $sr[1] eq 'CODE' 
+			? $str =~ s/($sr[0])/$sr[1]->($1)/ego
+			: $str =~ s/($sr[0])/$sr[1]/g;
+		return $str;
+	};
+}
+
+
+
 $meta->add_type({
 	name => 'ArrayToHash',
 	parent => scalar $meta->HashRef,
@@ -428,7 +457,7 @@ Coerce::Types::Standard - Coercing
 
 =head1 VERSION
 
-Version 0.000004
+Version 0.000005
 
 =cut
 
@@ -466,6 +495,14 @@ Accepts a string and coerces it into a HashRef, You can specify how to split the
 		much => 'coffee',
 	}
 
+=head2 StrSR
+
+Accepts a string and coerces via a search and replace regex generated by the arrayref passed into *by*, optionally the second argument can also be a callback function.
+
+	StrSR->by(['-', ':'])->coerce('beach_bar');
+	*-*-*-*-*-*-*
+	'beach:bar'
+
 =head2 ArrayToHash
 
 Accepts an ArrayRef and coerces it into a HashRef, the default behaviour here is to just dereference the array into a hash.
